/************************************************************


			        xBoard(TM) v2.0 Sample Programs
					------------------------------------

A Program to demonstrate the use of I2C RTC (Real Time Clock)
(DS1307). Here the DS1307 RTC Module is connected with an
AVR ATmega32 MCU by I2C Serial Bus.

This program reads time from the DS1307 and displays it in 
16x2 LCD Module.

DS1307 Connection
-----------------
SDA <-> PA1
SCL <-|  PA0 

When powered up the display is like this.

|----------------|
|   xBoard v2.0  |
|  06:07:48: PM  |
|----------------|


PLEASE SEE WWW.EXTREMEELECTRONICS.CO.IN FOR DETAILED 
SCHEMATICS,USER GUIDE AND VIDOES.

COPYRIGHT (C) 2008-2009 EXTREME ELECTRONICS INDIA
************************************************************/

#include <avr/io.h>
#include <util/delay.h>


#include "lcd.h"
#include "clock.h"


void Wait()
{
	uint8_t i;
	for(i=0;i<20;i++)
		_delay_loop_2(0);
}


void main()
{
	//Wait Util Other device startup
	_delay_ms(500);

	//Initialize the LCD Module
	LCDInit(LS_NONE);

	//Initialize the Clock Module
	if(!ClockInit())
	{
		//If we fail to initailize then warn user
		LCDClear();
		LCDWriteString("Error !");
		LCDWriteStringXY(0,1,"DS1307 Not Found");

		while(1); //Halt
	}

	LCDClear();
	
	
	char Time[12];	//hh:mm:ss AM/PM
	
	//Now Read and display time
	
	while(1)
	{
		
		//Get the Current Time as a String
		if(!GetTimeString(Time))
		{
			/*
			If return value is false then some error has occured
			
			Check
			 ->DS1307 Installed Properly
			 ->DIP Switch 1,2 are in on position
			*/

			LCDClear();
			LCDWriteString("   xBoard v2.0");
			LCDWriteStringXY(0,1,"I2C i/o Error !");
			
			while(1);//halt
		}

		//Display it
		LCDClear();
		LCDWriteString("   xBoard v2.0");
		LCDWriteStringXY(3,1,Time);

		//Hide the cursor
		LCDGotoXY(17,1);

		_delay_ms(500);
	}
	
	
}
